match_filter.detection.Detection
================================

.. currentmodule:: eqcorrscan.core.match_filter.detection

.. autoclass:: Detection

   .. rubric:: Methods

   .. autosummary::

      copy
      write

   .. automethod:: __init__
   .. automethod:: copy
   .. automethod:: write
